[% WRAPPER page.tt %]
  <h2>Modules</h2>

  [% IF modules.size > 0 %]
    <table id="modules" class="data">
      <tbody>
      [% FOREACH modules %]
        <tr class="[% IF loop.index() % 2 == 0 %]odd[%ELSE%]even[%END%]">
          <td><a href="module-[% name | html %].html">[% label | html %]</a></td>
          <td class="[% status %]">[% status %]</td>
        </tr>
      [% END %]
      </tbody>
    </table>
    
  [% ELSE %]
    <p>There are no modules defined</p>
  [% END %]
[% END %]
