[% WRAPPER page.tt %]
  <h2>Code repositories</h2>

  [% IF repositories.size > 0 %]
    [% FOREACH repositories %]
      [% IF modules.size > 0 %]
        <h3>[% label | html %]</h3>

        <table id="modules" class="data">
          <tbody>
          [% FOREACH modules %]
            <tr class="[% IF loop.index() % 2 == 0 %]odd[%ELSE%]even[%END%]">
              <td><a href="module-[% name | html %].html">[% label | html %]</a></td>
              <td class="[% status %]">[% status %]</td>
            </tr>
          [% END %]
          </tbody>
        </table>
      [% END %]
    [% END %]
  [% ELSE %]
    <p>There are no code repositories defined</p>
  [% END %]
[% END %]
