@import url(generic.css);

* {
  padding: 0px;
  margin: 0px;
}

body {
  background-color: #d9d9d9;
  color: #000000;
}

h1,h2,h3,h4,h5,h6 {
  padding: 2px;
  padding-left: 5px;
}

h1 {
  background-color: #cc0000;
  color: #ffffff;
  border-bottom: 1px solid #000000;  
  margin-bottom: 10px;
}

h2 {
  background-color: #cc0000;
  color: #000000;
  color: #ffffff;
  border-bottom: 1px solid #000000;  
  border-top: 1px solid #000000;  
}

#logo {
  position: absolute;
  top: 100px;
  right: 20px;
}



#menu {
  margin: 5px;
  padding: 3px;
  background-color: #660000;
  color: #ffffff;
  border-top: 1px solid #999999;
  border-left: 1px solid #999999;
  border-bottom: 1px solid #ffffff;
  border-right: 1px solid #ffffff;
}

#menu li {
  display: inline;
  padding-left: 2em;
//  padding: 3px;
//  margin: 2px;
}

#menu a {
  text-decoration: none;
  color: #ffffff;
  font-size: 1.4em;
}

#menu a:hover {
  color: #000000;
  background-color: #d9d9d9;
}


#footer {
  margin: 5px;
  padding: 3px;
  background-color: #660000;
  color: #ffffff;
  border-top: 1px solid #999999;
  border-left: 1px solid #999999;
  border-bottom: 1px solid #ffffff;
  border-right: 1px solid #ffffff;
}

#footer a {
  color: #ffffff;
}

.properties {
  border: 1px solid black;
  background-color: #ffffff;
  color: #000000;
  vertical-align: bottom;
  margin: 1em;
  border-spacing: 0px;
}

.properties td, .properties th {
  vertical-align: top;
}

.properties th {
  text-align: right
}

.data {
  border: 1px solid black;
  margin: 1em;
  border-spacing: 0px;
}

.data thead {
  background-color: #999999;
  color: #000000;
}

tbody tr.odd {
  background-color: #ffffff;
  color: #000000;
}

tbody tr.even {
  background-color: #d9d9d9;
  color: #000000;
}

tbody tr.even td, tbody tr.even th {
  border-top: 1px solid #a9a9a9;
  border-bottom: 1px solid #a9a9a9;
}

.filename, .md5sum {
  font-family: courier, monospace;
}

.failed {
  color: #000000;
  background-color: #ff0000;
}

.skipped {
  color: #000000;
  background-color: #ff00ff;
}

.pending {
  color: #000000;
  background-color: #ffff00;
}

.cached {
  color: #000000;
  background-color: #00ff00;
}

.success {
  color: #000000;
  background-color: #00ff00;
}





/**************************************************/
